{ Unit: Unit1
  ===========================================================================

  The contents of this file are subject to the Bluecave Public License V 1.1
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Very simple manifest resource editor/creator. Requires Borland Resource
    compiler for automated compiling support. 

  History:

    2001-11-27: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls;

type
  TForm1 = class(TForm)
    Button1: TButton;
    TabControl1: TTabControl;
    Memo1: TMemo;
    Edit1: TEdit;
    Label1: TLabel;
    Edit2: TEdit;
    Label2: TLabel;
    Edit3: TEdit;
    Label3: TLabel;
    Button2: TButton;
    Label4: TLabel;
    SaveDialog1: TSaveDialog;
    Button3: TButton;
    SaveDialog2: TSaveDialog;
    CheckBox1: TCheckBox;
    Button4: TButton;
    procedure TabControl1Change(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    SManifestTemplate: TStringList;
    procedure UpdateManifestData;
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
{$R Bluecave_Software_ManifestEditor.RES}

uses ShellAPI, Clipbrd;

procedure TForm1.TabControl1Change(Sender: TObject);
begin
  case TabControl1.TabIndex of
    0:
    begin
      Memo1.Visible := False;
//      Memo1.TabStop := False;
      Edit1.Visible := True;
      Label1.Visible := True;
      Edit2.Visible := True;
      Label2.Visible := True;
      Edit3.Visible := True;
      Label3.Visible := True;
      CheckBox1.Visible := True;
    end;
    1:
    begin
      UpdateManifestData;
      Memo1.Visible := True;
      Edit1.Visible := False;
      Label1.Visible := False;
      Edit2.Visible := False;
      Label2.Visible := False;
      Edit3.Visible := False;
      Label3.Visible := False;
      CheckBox1.Visible := False;
    end;
  end;
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  SManifestTemplate := TStringList.Create;
  SManifestTemplate.LoadFromFile(ExtractFilePath(ParamStr(0)) + 'ManifestTemplate.txt');
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  FreeAndNil(SManifestTemplate);
end;

procedure TForm1.UpdateManifestData;
begin
  Memo1.Text := Format(SManifestTemplate.Text, [Edit2.Text, Edit1.Text, Edit3.Text]);
end;

procedure TForm1.Button2Click(Sender: TObject);
var S: string;
begin
  UpdateManifestData;
  S := Edit1.Text;
  S := StringReplace(S, '.', '_', [rfReplaceAll, rfIgnoreCase]);
  S := StringReplace(S, ' ', '_', [rfReplaceAll, rfIgnoreCase]);
  SaveDialog1.FileName := S + '.manifest';
  if SaveDialog1.Execute then
    Memo1.Lines.SaveToFile(SaveDialog1.FileName);
end;

procedure TForm1.Button3Click(Sender: TObject);
var
  SL: TStringList;
  S: string;
begin
  UpdateManifestData;
  S := Edit1.Text;
  S := StringReplace(S, '.', '_', [rfReplaceAll, rfIgnoreCase]);
  S := StringReplace(S, ' ', '_', [rfReplaceAll, rfIgnoreCase]);
  SaveDialog2.FileName := S + '.rc';
  if SaveDialog2.Execute then
  begin
    Memo1.Lines.SaveToFile(ChangeFileExt(SaveDialog2.FileName, '.manifest'));
    try
      SL := TStringList.Create;
      SL.Add('/* Generated by Bluecave Manifest Editor 1.0 */');
      if CheckBox1.Checked then
        SL.Add('2 24 "' + ChangeFileExt(ExtractFileName(SaveDialog2.FileName), '.manifest"'))
      else
        SL.Add('1 24 "' + ChangeFileExt(ExtractFileName(SaveDialog2.FileName), '.manifest"'));
      SL.SaveToFile(SaveDialog2.FileName);
    finally
      FreeAndNil(SL);
    end;
    if ShellExecute(Handle, 'open', 'brc32.exe', PChar('-r ' + ExtractFileName(SaveDialog2.FileName)),
      PChar(ExtractFilePath(SaveDialog2.FileName)), SW_HIDE) <= 32 then
      ShowMessage('Borland Resource Compiler not found from path (brc32.exe)!')
    else
    begin
      ShowMessage('Resource ''' + ExtractFileName(SaveDialog2.FileName) +
       ''' compiled to ''' +
       ChangeFileExt(ExtractFileName(SaveDialog2.FileName), '.RES') + '''. Resource code snippet available in clipboard.');
      { delphi resource including string to clipboard } 
      Clipboard.AsText := '{$R ' + ChangeFileExt(ExtractFileName(SaveDialog2.FileName), '.RES') + '}';
    end;
  end;
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  Close;
end;

procedure TForm1.Button4Click(Sender: TObject);
begin
  ShowMessage(
    'Manifest Editor 1.0' + #13#10#13#10 +
    'Copyright 2001 (C) Bluecave Software' + #13#10 +
    'http://www.bluecave.net/' + #13#10 + #13#10 +
    'Copyright 2001 (C) Jouni Airaksinen' + #13#10 +
    'e-mail: Mintus@Codefield.com');
end;

end.
